==> library1.4.1.tar.bz2: library/books/get_book.php <==
<?php
  ///////////////////////////////////////////////////
  //Вернуть книгу
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 require_once "../utils/chlang.php";

  $title = $TEXT['book-nal-tit'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['book_id'])>20) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  $query_iskh = "SELECT
  book_name,
  e_book
  FROM tbl_book
  WHERE book_id = '".$_GET['book_id']."' ";
  $result_iskh = mysqli_query($dbcnx,$query_iskh);
  if(!$result_iskh) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
   $result_iskh2 = mysqli_fetch_array($result_iskh,MYSQLI_ASSOC);

  $zad_date = 0;

  echo "<div class='upd'><img alt='Ok' src='../skins/".$result2['skin']."/ok.png' /></div><div class='upd'>".$TEXT['book-vidano-now']."<a href='".$result_iskh2['e_book']."' target=_blank title='".$TEXT['book-ebook']."'><span class='informssilka'>".rep_back($result_iskh2['book_name'])."</span></a></div>";
  //*************************************
  //Информация для лога
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book4'];
  $what = $result_iskh2['book_name'].", ".$TEXT['log-id']." ".$_GET['book_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************
  $queryst = "INSERT INTO tbl_statistik ( `stat_id` , `book_id` , `user_id` , `data_vidachi` , `data_sdachi` , `r_data_sdachi`, `obr_id`, `zad_days` )
                         VALUES ( NULL , '".$_GET['book_id']."' , '".$result2['login_id']."' , CURRENT_DATE() , CURRENT_DATE() , CURRENT_DATE(), '1', ".$zad_date.")";
        if(mysqli_query($dbcnx,$queryst))
           {
             $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
             if(mysqli_query($dbcnx,$query2))
              {
                echo "<html><head>
                <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=".$result_iskh2['e_book']."' target=_blank />
                </head></html>";
              } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
           } else {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/books/get_book.php <==
<?php
  ///////////////////////////////////////////////////
  //Вернуть книгу
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 require_once "../utils/chlang.php";

  $title = $TEXT['book-vidano']."&nbsp;".$TEXT['book-ebook'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['book_id'])) {puterror($result2['skin'],$TEXT['error-book5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['book_id'])>20) {puterror($result2['skin'],$TEXT['error-book6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['book_id'] = rep($_GET['book_id']);

  $query_iskh = "SELECT
  book_name,
  e_book
  FROM tbl_book
  WHERE book_id = '".$_GET['book_id']."' ";
  $result_iskh = mysqli_query($dbcnx,$query_iskh);
  if(!$result_iskh) {puterror($result2['skin'],$TEXT['error-tbl3']); require_once "../utils/bottom_adm.php"; exit();}
   $result_iskh2 = mysqli_fetch_array($result_iskh,MYSQLI_ASSOC);

  $zad_date = 0;

  echo "<div class='upd'><img alt='Ok' src='../skins/".$result2['skin']."/ok.png' /></div><div class='upd'>".$TEXT['book-vidano-now']."<a href='".$result_iskh2['e_book']."' target=_blank title='".$TEXT['book-ebook']."'><span class='informssilka'>".rep_back($result_iskh2['book_name'])."</span></a></div>";
  //*************************************
  //Информация для лога
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-book4'];
  $what = $result_iskh2['book_name'].", ".$TEXT['log-id']." ".$_GET['book_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************
  $queryst = "INSERT INTO tbl_statistik ( `stat_id` , `book_id` , `user_id` , `data_vidachi` , `data_sdachi` , `r_data_sdachi`, `obr_id`, `zad_days` )
                         VALUES ( NULL , '".$_GET['book_id']."' , '".$result2['login_id']."' , CURRENT_DATE() , CURRENT_DATE() , CURRENT_DATE(), '1', ".$zad_date.")";
        if(mysqli_query($dbcnx,$queryst))
           {
             $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
             if(mysqli_query($dbcnx,$query2))
              {
                echo "<html><head>
                <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=".$result_iskh2['e_book']."' target=_blank />
                </head></html>";
              } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
           } else {puterror($result2['skin'],$TEXT['error-tbl4']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
